@@ -49,7 +49,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_HORIZONTAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+ //   new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -131,7 +131,7 @@ composition_central_horizontal_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_MIDDLE_HORIZONTAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -211,7 +211,7 @@ composition_central_vertical_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 200);
     if (new_day_button->background)
@@ -291,7 +291,7 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -387,7 +387,7 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -505,7 +505,7 @@ composition_now(WDB *new_day_button, gint layout)
             gtk_widget_set_size_request(new_day_button->box, xoffset+140+1, 37+15+106);
             break;
     }
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 /* Packing all to the box */
     if (new_day_button->background)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, xoffset, 37+15);
@@ -546,7 +546,7 @@ next_station_preset_now(gint layout)
         case PRESET_NOW_PLUS_THREE_H:
         case PRESET_NOW_PLUS_SEVEN:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_HORIZONTAL);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 138;
@@ -554,7 +554,7 @@ next_station_preset_now(gint layout)
             break; 
         case PRESET_NOW_PLUS_TWO:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_TWO);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 140;
@@ -562,7 +562,7 @@ next_station_preset_now(gint layout)
             break;
         case PRESET_NOW_PLUS_THREE_V:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_THREE_V);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 0, 0);
             x_width = 210;
@@ -571,7 +571,7 @@ next_station_preset_now(gint layout)
         default:
         case PRESET_NOW:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
                 gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
             x_width = 140;
@@ -673,7 +673,6 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     if (icon_buffer)
         /* create day icon image from buffer */
         new_day_button->icon_image = create_icon_widget(icon_buffer, icon, PRESET_NORMAL_IMAGE_SIZE, &app->clutter_objects_in_main_form);
-//        new_day_button->icon_image = create_icon_widget(icon_buffer, icon, icon_size, NULL);
     else
         new_day_button->icon_image = NULL;
 
@@ -851,13 +850,15 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
                     wind_speed = wind_speed * 1.6;
                     break;
         }
+/*	
         if (wind_speed < STRONG_WIND)
-            new_day_button->wind = gtk_image_new_from_file (buffer);
+//            new_day_button->wind = gtk_image_new_from_file (buffer);
         else{
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
-           new_day_button->wind = gtk_image_new_from_file (buffer);
+//           new_day_button->wind = gtk_image_new_from_file (buffer);
         }
+*/
     }
     new_day_button->box  = gtk_fixed_new();
 }
